using System;
using System.IO;
using System.Windows.Forms;
using Microsoft.Ink;

namespace CogArtTech.Tablet
{
    public partial class Form1 : Form
    {
        private string currentFileName = string.Empty;
        private InkCollector inkCollector;
        public Form1()
        {
            InitializeComponent();
            // Create a new ink collector that uses pnlHandwritingSurface as
            //the handwriting surface.
            inkCollector = new InkCollector(pnlWritingSurface.Handle);

            // Turn the ink collector on
            inkCollector.Enabled = true;  
        }
        
        private void CreateMenu()
        {
            MenuItem fileMenu = new MenuItem("&File");
            MainMenu mainMenu = new MainMenu();
        }
        
        private void Form1_Load(object sender, EventArgs e)
        {
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void recognizeToolStripMenuItem_Click(object sender, EventArgs e)
        {
            //Do the handwriting recognition
            string str = inkCollector.Ink.Strokes.ToString();
            if(str != null && str.Length>0)
            {
                MessageBox.Show(str);
            }else
            {
                MessageBox.Show("Cannot recognize handwriting");
            }
        }

        private void clearToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Clear();
        }

        /// <summary>
        /// Clears the panel surface and <see cref="Strokes"/> in the 
        /// <see cref="InkCollector"/>.
        /// </summary>
        /// Created: 1/15/2007 8:26 PM
        /// Created By: Bob Reselman
        private void Clear()
        {
            //Clear out the strokes that you made on the surface
            inkCollector.Ink.DeleteStrokes();
            //Clear the writing surface panel of the ink rendering
            pnlWritingSurface.Refresh(); 
        }

        private void saveToolStripMenuItem_Click(object sender, EventArgs e)
        {
            byte[] bytes = inkCollector.Ink.Save(PersistenceFormat.InkSerializedFormat);
            this.Save(bytes);
        }

        /// <summary>
        /// Saves the specified bytes.
        /// </summary>
        /// <param name="bytes">The bytes of the <see cref="Ink"/> object.S</param>
        /// Created: 1/15/2007 8:27 PM
        /// Created By: Bob Reselman
        private void Save(byte[] bytes)
        {
            //Get a file save dialog
            SaveFileDialog dlgSave = new SaveFileDialog();
            //Filter for Ink Serialization Format
            dlgSave.Filter = "ISF files (*.isf)|*.isf| All files (*.*)|*.*";
            if (dlgSave.ShowDialog() == DialogResult.OK)
            {
                //Make a stream into which you save the bytes
                Stream stream = dlgSave.OpenFile();
                if (stream != null)
                {
                    //Save the bytes
                    stream.Write(bytes, 0, bytes.Length);
                    //Close the file
                    stream.Close();
                    //Set the application variable to reflect the 
                    //current filename in play
                    currentFileName = dlgSave.FileName;
                }
            }
        }

        private void openToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Clear();
            this.Open(inkCollector);
        }

        /// <summary>
        /// Opens an ISF file and attaches the data to the
        /// ink of an <see cref="InkCollector"/> object.
        /// </summary>
        /// <param name="collector">The <see cref="InkCollector"/> object against
        /// which to attach the retrieved <see cref="Ink"/></param>
        /// Created: 1/15/2007 8:23 PM
        /// Created By: Bob Reselman
        private void Open(InkCollector collector)
        {
            //Get a file open dialog
            OpenFileDialog dlgOpen = new OpenFileDialog();
            //Filter for Ink Serialization Format
            dlgOpen.Filter = "ISF files (*.isf)|*.isf| All files (*.*)|*.*";
            if (dlgOpen.ShowDialog() == DialogResult.OK)
            {
                //Get the Ink Stream
                Stream stream = dlgOpen.OpenFile();
                if (stream != null && stream.Length > 0)
                {
                    //Make a byte array the size of the stream
                    byte[] bytes = new byte[stream.Length];
                    //Read the stream into the byte array
                    if (stream.Read(bytes, 0, bytes.Length) == stream.Length)
                    {
                        Ink ink = new Ink();
                        //Load the bytes into the newly created Ink object
                        ink.Load(bytes);
                        //Disable the InkCollector so that you can add the local
                        //Ink object that has the byte data
                        collector.Enabled = false;
                        //Assign the local Ink object to the InkCollector
                        collector.Ink = ink;
                        //Enable the InkCollector so that Ink can be addedsss
                        collector.Enabled = true;
                    }
                    //Close up shops
                    stream.Close();
                }
            }
        }

        private void newToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Clear();
            currentFileName = string.Empty;
        }
    }
}